@@ -1,4 +1,4 @@
-/* Copyright 2007, 2008 Matthew Barnes
+/* Copyright 2007-2009 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -20,7 +20,7 @@
 
 #include <errno.h>
 #include <string.h>
-#include <wait.h>
+#include <sys/wait.h>
 
 #ifdef HAVE_WORDEXP_H
 #include <wordexp.h>
