@@ -1,4 +1,4 @@
-/* Copyright 2007, 2008 Matthew Barnes
+/* Copyright 2007-2009 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -73,29 +73,6 @@ tree_view_show_popup_menu (GdkEventButton *event,
                            GtkTreeViewColumn *column)
 {
         GtkMenu *menu;
-        GtkWidget *view;
-        const gchar *column_name;
-        const gchar *column_title;
-        GvaGameStoreColumn column_id;
-        gchar *label, *tooltip;
-
-        view = gtk_tree_view_column_get_tree_view (column);
-        g_object_set_data (G_OBJECT (view), "popup-menu-column", column);
-        column_name = g_object_get_data (G_OBJECT (column), "name");
-        gva_columns_lookup_id (column_name, &column_id);
-        column_title = gva_columns_lookup_title (column_id);
-
-        /* Update the "Remove Column" item in the popup menu. */
-        label = g_strdup_printf (
-                _("Remove %s Column"), column_title);
-        tooltip = g_strdup_printf (
-                _("Remove the \"%s\" column from the game list"),
-                column_title);
-        g_object_set (
-                GVA_ACTION_REMOVE_COLUMN, "label",
-                label, "tooltip", tooltip, NULL);
-        g_free (tooltip);
-        g_free (label);
 
         menu = GTK_MENU (gva_ui_get_managed_widget ("/game-popup"));
 
@@ -283,6 +260,18 @@ gva_tree_view_update (GError **error)
         if (!success)
                 return FALSE;
 
+        if (gva_tree_view_get_selected_view () == 2)
+        {
+                GtkTreeView *view;
+                GtkTreeModel *model;
+
+                view = GTK_TREE_VIEW (GVA_WIDGET_MAIN_TREE_VIEW);
+                model = gtk_tree_view_get_model (view);
+
+                if (gtk_tree_model_iter_n_children (model, NULL) == 0)
+                        gtk_action_activate (GVA_ACTION_SEARCH);
+        }
+
         name = gva_tree_view_get_last_selected_game ();
         if (name != NULL)
                 gva_tree_view_set_selected_game (name);
@@ -509,43 +498,38 @@ gva_tree_view_get_selected_game (void)
  * gva_tree_view_set_selected_game:
  * @game: the name of a game
  *
- * Selects the row corresponding to @game.  If the row is invisible in the
- * current view, select the first row instead.  The function also calls
+ * Selects the row corresponding to @game.  If the row is invisible in
+ * the current view, unselect all tree view rows.  The function also calls
  * gva_tree_view_set_last_selected_game() so that the selected game will be
  * persistent across sessions.
  **/
 void
 gva_tree_view_set_selected_game (const gchar *game)
 {
-        GtkTreeModel *model;
         GtkTreeView *view;
         GtkTreePath *path;
-        GtkTreeIter iter;
 
         g_return_if_fail (game != NULL);
 
         view = GTK_TREE_VIEW (GVA_WIDGET_MAIN_TREE_VIEW);
         path = gva_tree_view_lookup (game);
 
-        /* If the game is visible in the current view, put the cursor on it.
-         * Otherwise just select the root path. */
+        /* If the game is visible in the current view, put the cursor
+         * on it and scroll to it.  Otherwise unselect everything. */
         if (path != NULL)
         {
-                gtk_tree_view_set_cursor (view, path, NULL, FALSE);
                 gtk_widget_grab_focus (GTK_WIDGET (view));
+                gtk_tree_view_set_cursor (view, path, NULL, FALSE);
+                gtk_tree_view_scroll_to_cell (view, path, NULL, TRUE, .5, .0);
+                gtk_tree_path_free (path);
         }
         else
-                path = gtk_tree_path_new_first ();
+        {
+                GtkTreeSelection *selection;
 
-        /* If we have a path to a visible game, scroll to it.  Note that
-         * we don't really need the GtkTreeIter here; we're just testing
-         * whether the path is valid. */
-        model = gtk_tree_view_get_model (view);
-        if (gtk_tree_model_get_iter (model, &iter, path))
-                gtk_tree_view_scroll_to_cell (
-                        view, path, NULL, TRUE, 0.5, 0.0);
-
-        gtk_tree_path_free (path);
+                selection = gtk_tree_view_get_selection (view);
+                gtk_tree_selection_unselect_all (selection);
+        }
 
         gva_tree_view_set_last_selected_game (game);
 }
